@@ -36,11 +36,41 @@ def iq_login(verbose = False, iq = None, checkConnection = False,email=None, pas
         
 
     return iq
+def timeframe_to_sec(timeframe):
+    # Timeframe dictionary
+    TIMECANDLE = {
+        "S30": 30,
+        "M1": 60,
+        "M2": 120,
+        "M3": 180,
+        "M4": 240,
+        "M5": 300,
+        "M15": 900,
+        "M30": 1800,
+        "H1": 3600,
+            
+    }
+    return TIMECANDLE[timeframe]  
 
+def time_trade(timeframe):
+    # Timeframe dictionary
+    TIMETTRADE = {
+        "S30": 1,
+        "M1": 1,
+        "M2": 2,
+        "M3": 3,
+        "M4": 4,
+        "M5": 5,
+        "M15": 15,
+        "M30": 30,
+        "H1": 60,
+            
+    }
+    return TIMETTRADE[timeframe]        
 
 def iq_buy_binary(iq,contract,symbol,timeframe):
-    
-    done,id = iq.buy(contract,symbol,"call",timeframe)
+    timeframe = time_trade(timeframe)
+    done,id = iq.buy(contract,symbol,"call",int(timeframe))
     
     if not done:
         print('Error call')
@@ -51,8 +81,8 @@ def iq_buy_binary(iq,contract,symbol,timeframe):
 
 
 def iq_sell_binary(iq,contract,symbol,timeframe):
-    
-    done,id = iq.buy(contract,symbol,"put",timeframe)
+    timeframe = time_trade(timeframe)
+    done,id = iq.buy(contract,symbol,"put",int(timeframe))
     
     if not done:
         print('Error put')
@@ -62,7 +92,6 @@ def iq_sell_binary(iq,contract,symbol,timeframe):
     return id
   
 def iq_get_candles(iq,symbol,timeframe):
-    timeframe = timeframe * 60
     iq_login(iq = iq, checkConnection = True)
     return  iq.get_candles(symbol, int(timeframe), 1000, time.time())
 
@@ -74,19 +103,17 @@ def iq_get_all_candles(iq,symbol,timeframe,start_candle):
     
     for x in range(1):
         iq_login(iq = iq, checkConnection = True)
-        timeframe = timeframe * 60
-        data = iq.get_candles(symbol, 300, 1000, start_candle)
+        data = iq.get_candles(symbol, int(timeframe), 1000, start_candle)
         start_candle = data[0]['to']-1
         final_data.extend(data)
     return final_data
 
 def iq_get_data(iq,symbol,symbols,timeframe): 
-    timeframe = timeframe * 60
-    start_candle = time.time()
     actives = symbols
+    timeframe = timeframe_to_sec(timeframe)
     final_data = pd.DataFrame()
     for active in actives:
-        current = iq_get_all_candles(iq,symbol,int(timeframe),start_candle)
+        current = iq_get_all_candles(iq,symbol,timeframe,time.time())
         main = pd.DataFrame()
         useful_frame = pd.DataFrame()
         for candle in current:
@@ -103,10 +130,10 @@ def iq_get_data(iq,symbol,symbols,timeframe):
     final_data = final_data.loc[~final_data.index.duplicated(keep = 'first')]
     return final_data
     
-def iq_fast_data(iq,symbol,timeframe): 
+def iq_get_fastdata(iq,symbol,timeframe): 
     iq_login(iq = iq, checkConnection = True)
-    timeframe = timeframe * 60
-    candles = iq.get_candles(symbol,int(timeframe),300,time.time())
+    timeframe = timeframe_to_sec(timeframe)
+    candles = iq.get_candles(symbol,int(timeframe),50,time.time())
     useful_frame = pd.DataFrame()
     main = pd.DataFrame()
     for candle in candles:
@@ -140,6 +167,27 @@ def iq_market_isOpen(iq):
 
 
 
-def iq_get_payout(iq,symbol='EURUSD',typed='turbo'):
+def iq_get_payout(iq,symbol=None,typed='turbo'):
     payout = iq.get_all_profit()   
     return payout[symbol][typed]
+
+def iq_get_remaning(iq,timeframe):
+    t = time_trade(timeframe)
+    remaning_time=iq.get_remaning(t)
+    purchase_time=remaning_time
+    return purchase_time
+
+def iq_checkwin(iq,id):
+    return iq.check_win_v3(id)
+
+
+def iq_book_live(iq,symbol):
+    return iq.start_mood_stream(symbol)
+
+def iq_book_history(iq,symbol):
+    return iq.get_traders_mood(symbol)
+    
+    
+
+
+    
